@@ -95,7 +95,7 @@ def handle_exception(retry_times=0, error_detail_level=0, is_throw_error=False,
     return _handle_exception
 
 
-def keep_circulating(time_sleep=0.001, exit_if_function_run_sucsess=False, is_display_detail_exception=True, block=True):
+def keep_circulating(time_sleep=0.001, exit_if_function_run_sucsess=False, is_display_detail_exception=True, block=True, daemon=False):
     """间隔一段时间，一直循环运行某个方法的装饰器
     :param time_sleep :循环的间隔时间
     :param exit_if_function_run_sucsess :如果成功了就退出循环
@@ -125,12 +125,13 @@ def keep_circulating(time_sleep=0.001, exit_if_function_run_sucsess=False, is_di
             if block:
                 return ___keep_circulating()
             else:
-                threading.Thread(target=___keep_circulating, ).start()
+                threading.Thread(target=___keep_circulating, daemon=daemon).start()
 
         return __keep_circulating
 
     return _keep_circulating
 
+
 def synchronized(func):
     """线程锁装饰器，可以加在单例模式上"""
     func.__lock__ = threading.Lock()
@@ -611,8 +612,6 @@ class _Test(unittest.TestCase):
 
         f()
 
-
-
     @unittest.skip
     def test_run_many_times(self):
         """测试运行5次"""
